@@ -20,27 +20,37 @@ class SpacyFactor(object):
             self.description = description
 
     @staticmethod
-    def match_case(span_text, suggestions):
+    def match_case(span: Span, suggestions):
         """
         suggestions respect original casing
         ex. purchase -> buy (lower)
         ex. PURCHASE -> BUY (upper)
         ex. Purchase -> Buy (title)
         """
-
+        span_text = span.text
         try:
             if len(span_text.strip()):
                 words = span_text.split(" ")
+                is_sent_start = len(span) and span[0].is_sent_start
                 if words[0].islower():
-                    # todo: exclude I and capitalized proper nouns
-                    suggestions = [s.lower() for s in suggestions]
-
-                # len condition: exclude capitalization caused by "I"
+                    # this should exclude I
+                    # todo - capitalized proper nouns
+                    suggestions = [
+                        " ".join(
+                            [
+                                word.lower() if word != "I" else word
+                                for word in sug.split()
+                            ]
+                        )
+                        for sug in suggestions
+                    ]
                 elif len(words[0]) > 1 and words[0].isupper():
+                    # len condition is to exclude capitalization caused by "I"
                     suggestions = [s.upper() for s in suggestions]
-
-                # title case - first letter check & conversion due to contractions
-                elif len(words[0]) > 1 and words[0][0].isupper():
+                elif (len(words[0]) > 1 and words[0][0].isupper()) or (
+                    is_sent_start and len(span[0]) == 1
+                ):
+                    # title case - first letter check & conversion due to contractions
                     for i, s in enumerate(suggestions):
                         if len(s.strip()):
                             s_words = s.split(" ")
@@ -91,7 +101,7 @@ class SpacyFactor(object):
         )
 
         if cased:
-            suggestions = self.match_case(spacy_span.text, suggestions)
+            suggestions = self.match_case(spacy_span, suggestions)
 
         if describer:
             description = describer(spacy_span)
